# pyplus
## Description

> Now `xystudio-all` library has stopped supporting. It is recommended that all projects use a safer pyplus library, and it has some new interfaces have been added on the basis of the original xystudio-all library.
> This library must use python version>=3.7 and it cannot install after 3.14.Recommed 3.12.

For the expansion of python content, it covers science, debugging and other fields.

---
## Version name rule
Version types are `dev`,`a`,`b`,`r`,`rc`,`post`.

Version type `dev` mean develop.It stores develop version.It has more bugs.

Version type `a` mean alpha.It stores early test.It has more bugs.

Version type `b` mean beta.It stores late test.It has more bugs.

Version type `rc` mean release candidate.It stores late version.The offical version will be relases soon.It has fewer bugs.

Version type `r` mean release.It stores offical version.

Version type `post` stores vulnerability for the relase version.


---

## Library document
Documents have not been completed.

---
## Setup method
run `python setup.py install` or `pip install python-plus-tools` to install the package.

## Check setup successful
After setup complete,open the python,input
```python
import pyplus
```
If no error,download successful.

---